function [Opt_a, Opt_W, OptProfit, Profit_costmin, Cost_costmin, W_costmin] = BenchmarkOptContract(m,rho,step,mgnfy);

% Computes the benchmark optimal contract
% 'magnify' = 1; =100 if we want to magnify payoffs by 100 to examine the "high-steaks" scenario

[F, F_a, f_kernel, x, a_est, aa, a_max, A] = Density_spline;

magnify = mgnfy;

wLin = @(xx,alpha) (100+alpha.*xx);
wBonus = @(xx,B) (100 + B.*(xx>2000));
WW = magnify.*[wLin(x,0) wLin(x,0.001) wLin(x,0.01) wLin(x,0.04) wLin(x,0.1) wBonus(x,40) wBonus(x,80)];

% Set the parameters of the model
param = Estimate_parameters(rho,magnify);
beta = param(1);
eps = param(2); 
I = param(3);

p = 1/eps;
c0 = exp(-beta./eps);

vp = @(om) (om.^(-rho));
U = @(om) ( (om.^(1-rho)) / (1-rho) );
uinv = @(z) (((1-rho).*z).^(1./(1-rho)));

cost = @(a) ((c0./(p+1)).*(a.^(p+1)) - I.*a);
cp = @(a) (c0.*(a.^p) - I);

a_grid = [2000:step:a_max];

for k=1:7
    Profit_Base(k,1) = trapz(x, (m.*x - WW(:,k)).*F(:,a_est(k)));
    IR(k,1) = trapz(x, U(WW(:,k)).*F(:,a_est(k))) - cost(a_est(k));
end

N = length(x);
cc = (max(x)-min(x))/N;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Status = strings(7,length(a_grid));

% Compute the optimal contract given IR(w_ind)
for ind = 2:7 % Run into a loop

Profit_costmin(ind,1:1999) = -inf;

for a=a_grid
    [ind a]

% For every a, find the cost-minimizing contract
cvx_begin quiet
    variables v(N,1)
    minimize( cc.*sum( (((1-rho).*v).^(1./(1-rho))).*F(:,a)) )
    subject to
        for a_IC = [1570:5:a_max] % Global IC constraint
            cc.*sum(v.*F(:,a)) - cost(a) >= cc.*sum(v.*F(:,a_IC)) - cost(a_IC);
        end
        cc.*sum(v.*F_a(:,a)) >= cp(a); % Local IC constraint
        cc.*sum(v.*F(:,a)) - cost(a) >= IR(ind); % IR constraint
        v >= U(magnify.*100); % LL constraint
        v(2:end) >= v(1:end-1); % Monotonicity constraint
cvx_end

Status(ind,a) = cvx_status;

W_costmin(:,a) = uinv(v);
Cost_costmin(ind,a) = trapz(x, W_costmin(:,a).*F(:,a));
Cost_cvx(ind,a) = cvx_optval;

Profit_costmin(ind, a) = trapz(x,m.*x.*F(:,a)) - Cost_costmin(ind,a); % Profit corresponding to cost-minimizing contract

% Check that the contract implements the target effort
U_agent = zeros(max(a_grid),1);
for a_chk = [1570:1:a_max]
    U_agent(a_chk) = trapz(x, v.* F(:,a_chk)) - cost(a_chk);
end
a_impl(ind,a) = max(find(U_agent == max(U_agent)));

end

[OptProfit(ind) Opt_a(ind)] = max(Profit_costmin(ind,:)); % Profit and effort corresponding to profit-maximizing contract
Opt_W(:,ind) = W_costmin(:,Opt_a(ind)); % Optimal contract

end
