function [] = Heterogeneous_RRA;

load('DP_Data')
[f_0c x] = KernelEst(DP_0c);
[f_01c x] = KernelEst(DP_01c);
[f_1c x] = KernelEst(DP_1c);
[f_4c x] = KernelEst(DP_4c);
[f_10c x] = KernelEst(DP_10c);
[f_40c x] = KernelEst(DP_40c);
[f_80c x] = KernelEst(DP_80c);

k = 3; %Epanechnikov = 1 ; Biweight = 2 ; Triweight = 3 ; Gaussian = 4 (2nd degree)
f_0c = f_0c(:,k) ./trapz(x,f_0c(:,k));
f_01c = f_01c(:,k) ./trapz(x,f_01c(:,k));
f_1c = f_1c(:,k) ./trapz(x,f_1c(:,k));
f_4c = f_4c(:,k) ./trapz(x,f_4c(:,k));
f_10c = f_10c(:,k) ./trapz(x,f_10c(:,k));
f_40c = f_40c(:,k) ./trapz(x,f_40c(:,k));
f_80c = f_80c(:,k) ./trapz(x,f_80c(:,k));

A = [mean(DP_01c) mean(DP_1c) mean(DP_4c) mean(DP_10c) mean(DP_40c) mean(DP_80c)];
wLin = @(xx,alpha) (100+alpha.*xx);
wBonus = @(xx,B) (100 + B.*(xx>2000));

FF = [f_01c f_1c f_4c f_10c f_40c f_80c];
WW = [wLin(x,0.001) wLin(x,0.01) wLin(x,0.04) wLin(x,0.1) wBonus(x,40) wBonus(x,80)];

i = 3; j = 4;
h = (FF(:,j) - FF(:,i)) ./ (A(:,j) - A(:,i));

U = @(money,risk) (money.^(1-risk))./ (1-risk);
I = @(w,risk) (trapz(x, U(w,risk).*h));

N = 61;
theta = linspace(0,0.6,N)';
theta0 = 0.3;

p(:,1) = ones(N,1) ./ N;
p(:,2) = 0.01.* normpdf(theta, 0.3,0.075)  / sum(0.01.* normpdf(theta, 0.3,0.075));
p(:,3) = 0.01.* normpdf(theta, 0.3,0.15)  / sum(0.01.* normpdf(theta, 0.3,0.15));

w_A = WW(:,i); 
w_B = WW(:,j);
a_Bth = A(j) .* ones(N,1);
eps = log((A(:,j) / A(:,i))) / log(I(w_B, theta0) / I(w_A, theta0));

for k=1:N
    a_Ath(k,1) = a_Bth(k).*((I(w_A, theta(k)) ./ I(w_B, theta(k)) ).^eps);
end

for ind = 1:3

a_A(ind) = sum(p(:,ind).*a_Ath);
a_B(ind) = sum(p(:,ind).*a_Bth);

eps0(ind) = (log(a_A(ind)) - log(a_B(ind))) ./ (log(I(w_A,theta0)) - log(I(w_B,theta0)));

% Two cases: 1 = piece-rate contracts ; 2 = bonus contracts
opt = 1;

alpha = linspace(0.001,1,1000);
bb = linspace(1,500,length(alpha));

for l=1:length(alpha)

    if opt == 1
    	w_l = 100 + alpha(l).*x;
    elseif opt == 2
        w_l = 100 + bb(l).*(x>=2000);
    end
    for k = 1:N
        denominator(k,1) = a_Ath(k).*((I(w_l,theta(k)) ./ I(w_A,theta(k))).^eps);
    end
    ratio(l,ind) = a_A(ind) .*((I(w_l,theta0)./I(w_A,theta0)).^eps0(ind)) ./ (sum(p(:,ind).*denominator));
end

end

figure('Name','Figure 5: Prediction error with unobserved heterogeneity in the coefficient of RRA','NumberTitle','off','units','normalized','outerposition',[0 0 1 1])
set(0,'defaultTextInterpreter','latex');

subplot(1,2,1); plot(theta, p, 'o', 'MarkerSize',8); set(gca,'FontSize',20);
xlabel('Coefficient of RRA $\rho$','FontSize',30); ylabel('$\Pr\{\rho\}$','FontSize',30);

subplot(1,2,2); semilogx(alpha, 100.*(ratio-1), 'linewidth', 4); set(gca,'FontSize',20);
xticks([0.001 0.01 0.1 1 10 100])
xticklabels({'0.001','0.01','0.1','1','10','100'})
xlabel('Piece Rate $\alpha$','FontSize',30); ylabel('Prediction error $\%$','FontSize',30);

fig = gcf;
fig.Color = 'w';  
saveas(gcf,'../Figure5.png')