function [] = Heterogeneous_elasticity;

rho_true = 0.3;
rho_pred = 0.3;

load('DP_Data')
[f_01c x] = KernelEst(DP_01c); k = 3; f_01c = f_01c(:,k) ./trapz(x,f_01c(:,k));
[f_1c x] = KernelEst(DP_1c); f_1c = f_1c(:,k) ./trapz(x,f_1c(:,k));
[f_4c x] = KernelEst(DP_4c); f_4c = f_4c(:,k) ./trapz(x,f_4c(:,k));
[f_10c x] = KernelEst(DP_10c); f_10c = f_10c(:,k) ./trapz(x,f_10c(:,k));
[f_40c x] = KernelEst(DP_40c); f_40c = f_40c(:,k) ./trapz(x,f_40c(:,k));
[f_80c x] = KernelEst(DP_80c); f_80c = f_80c(:,k) ./trapz(x,f_80c(:,k));

A = [mean(DP_01c) mean(DP_1c) mean(DP_4c) mean(DP_10c) mean(DP_40c) mean(DP_80c)];
wLin = @(xx,alpha) (100+alpha.*xx);
wBonus = @(xx,B) (100 + B.*(xx>2000));
WW = [wLin(x,0.001) wLin(x,0.01) wLin(x,0.04) wLin(x,0.1) wBonus(x,40) wBonus(x,80)];

FF = [f_01c f_1c f_4c f_10c f_40c f_80c];
i = 4; j = 3;

w_A = WW(:,i); % wLin(x,0.1);
w_B = WW(:,j); % wLin(x,0.04);

h = (FF(:,j) - FF(:,i)) ./ (A(:,j) - A(:,i));
U = @(money,risk) (money.^(1-risk))./ (1-risk);
I = @(w,risk) (trapz(x, U(w,risk).*h));

eps_bar = log((A(:,j) / A(:,i))) / log(I(w_B, rho_pred) / I(w_A, rho_pred));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

N = 600;

eps = linspace(0,1,N+1); eps = eps(2:end);
Deps = eps(2)-eps(1);

SHAPE = [3 10 20];

for ind = 1:3
        
a_B = A(j);
ratioI = I(w_A,rho_true) ./ I(w_B,rho_true);
ratioI_pred = I(w_A,rho_pred) ./ I(w_B,rho_pred);

a_A = ratioI.^eps;

% Gamma distribution

shape = SHAPE(ind);
Scale_gamma(ind) = fsolve(@(scale) log(sum(gampdf(eps,shape,scale) .* Deps .* (ratioI.^eps))) / log(ratioI_pred) - eps_bar, eps_bar);

p(ind,:) = gampdf(eps,shape,Scale_gamma(ind)) .* Deps;
F(ind,:) = gamcdf(eps,shape,Scale_gamma(ind));

for i=2:N
    F_cum(ind,i) = trapz(eps(1:i), F(ind,1:i));
end

a_A_bar = sum(p(ind,:).*a_A);

ALPHA = linspace(0.001,1,1000)';
for i = 1:length(ALPHA)
    
    w = wLin(x, ALPHA(i));
    
    Bias(i,ind) = 100.*sum(p(ind,:).*a_A.*((I(w,rho_pred)./I(w_A,rho_pred)).^eps_bar)) ./ sum(p(ind,:).*a_A.*((I(w,rho_true)./I(w_A,rho_true)).^eps)) - 100;
    
end

end

%%%%%%%%%%%%%%%%%%%%%%%%%%%

figure('Name','Figure 4: Prediction error with unobserved heterogeneity in elasticity of effort','NumberTitle','off','units','normalized','outerposition',[0 0 1 1])
set(0,'defaultTextInterpreter','latex');

subplot(1,2,1); plot(eps(find(eps<=0.1)),p(:,find(eps<=0.1)), 'o', 'MarkerSize',8); set(gca,'FontSize',20); 
hold on
xlabel('Elasticity $\epsilon_\phi$','FontSize',35); ylabel('$p_\phi$','FontSize',35);

subplot(1,2,2); semilogx(ALPHA,Bias, 'linewidth', 4); set(gca,'FontSize',20);
xticks([0.001 0.01 0.1 1 10 100])
xticklabels({'0.001','0.01','0.1','1','10','100'})
xlabel('Piece Rate $\alpha$','FontSize',30); ylabel('Prediction error $\%$','FontSize',30);

fig = gcf;
fig.Color = 'w';  
saveas(gcf,'../Figure4.png')