function [ParametersList, Table_homogeneous, Table_hybrid] = OptAdjustments_AB(mgnfy, stepsize);
% Finds an optimal adjustment

magnify = mgnfy;
step = stepsize;

ParamList2 = [0.3 0.3 0.3 0.1 0.5 ; 0.2 0.15 0.25 0.2 0.2];
ParamList2(2,:) = ParamList2(2,:).*magnify;
for i=1:5
	rho = ParamList2(1,i);
	m = ParamList2(2,i);
	[Opt_a(i,:), Opt_W(:,:,i), OptProfit(i,:), Profit_costmin(:,:,i), Cost_costmin(:,:,i) W_costmin(:,:,i)] = BenchmarkOptContract(m, rho,step, magnify);
end

ParamList = [0.3 0.3 0.3 0.1 0.5 0.3 0.3 ; 0.3 0.3 0.3 0.3 0.3 0.1 0.5 ; 0.2 0.15 0.25 0.2 0.2 0.2 0.2];
ParamList(3,:) = ParamList(3,:).*magnify;
[F, F_a, f_kernel, x, a_est, aa, a_max, A] = Density_spline;

wLin = @(xx,alpha) (100+alpha.*xx);
wBonus = @(xx,B) (100 + B.*(xx>2000));
WW = magnify.*[wLin(x,0) wLin(x,0.001) wLin(x,0.01) wLin(x,0.04) wLin(x,0.1) wBonus(x,40) wBonus(x,80)];

% Generate all pairs of A-B tests
NN=1;
for n=2:length(aa)-1
    for nn=n+1:length(aa)
        if n ~= nn
            cnt(NN,:)=[n nn NN];
            NN = NN+1;
        end
    end
end

cnt_h = 1; cnt_nonh = 1;
for counter=1:length(cnt)
    if (cnt(counter,1) <= 5 && cnt(counter,2) <= 5) || (cnt(counter,1) >= 6 && cnt(counter,2) >= 6)
        cnt_nonhybrid(cnt_nonh,:) = counter;
        cnt_nonh=cnt_nonh+1;
    else
        cnt_hybrid(cnt_h,:) = counter;
        cnt_h=cnt_h+1;
    end
end

% Generate f_hat and f_a for each A-B test
for counter=1:15
    F_Hat(:,counter) = f_kernel(:,cnt(counter,1));
    F_Hat_a(:,counter) = (f_kernel(:,cnt(counter,2))-f_kernel(:,cnt(counter,1)))./ trapz(x,x.*(f_kernel(:,cnt(counter,2))-f_kernel(:,cnt(counter,1))));
end

for param_iter = 1:7
        
RHO_true = ParamList(1, param_iter);
rho = ParamList(2, param_iter); %Principal's guess
m = ParamList(3, param_iter);    

if param_iter <= 5
    param_cntr = param_iter;
else
    param_cntr = 1;
end

IR_extrap = GenerateIR(rho,magnify);

for IR_ind = 2:7

Summary = zeros(15, 26);

param = Estimate_parameters(RHO_true,magnify);
beta = param(1);
eps = param(2); 
I = param(3);
p = 1/eps;
c0 = exp(-beta./eps);

U = @(om) ( (om.^(1-rho)) ./ (1-rho) );
uinv = @(z) (((1-rho).*z).^(1./(1-rho)));

U_true = @(om) ( (om.^(1-RHO_true)) ./ (1-RHO_true) );

cost = @(a) ((c0./(p+1)).*(a.^(p+1)) - I.*a);

N = length(x);
cc = (max(x)-min(x))/N;

% Compute effort corresponding to each treatment per the estimated model

% Compute principal's profit corresponding to each contract
for ind=1:7
    for l=1:length(A)
        U_agent(l,ind) = trapz(x,U_true(WW(:,ind)) .* F(:,A(l)))- cost(A(l));
    end
end
[maxU indA] = max(U_agent);
a_model = A(indA)';

% Compute agent's outside option and firm's profit based on model for each treatment
IR = maxU';
for ind=1:7
    Profit_Base(ind,1) = trapz(x, (m.*x - WW(:,ind)).*F(:,a_model(ind)));
end

% Compute optimal perturbations and evaluate their performance

% Generate empty payoff matrices
Profit_Est = zeros(15,9); % [OptProfit, w_A, w_B, Profit(w_A), Profit(opt_pert), Profit(Costmin_A), Profit(Costmin_B), Profit(Costmin*), Profit(opt_pert_lin)]
Profit_True = zeros(15,9); % [OptProfit, w_A, w_B, Profit(w_A), Profit(opt_pert), Profit(Costmin_A), Profit(Costmin_B), Profit(Costmin*), Profit(opt_pert_lin)]
IR_True = zeros(15,4); %[w_A, w_B, IR(w_A), IR(w_pert*)]

OptP = [ones(5,1).*OptProfit(param_cntr,2) ; ones(4,1).*OptProfit(param_cntr,3) ; ones(3,1).*OptProfit(param_cntr,4) ; ones(2,1).*OptProfit(param_cntr,5) ; ones(1,1).*OptProfit(param_cntr,6)] ;% ones(5,1).*OptProfit(param_cntr,7)];
Profit_Est(:,1:3) = [OptP cnt(:,1:2)];
Profit_True(:,1:3) = [OptP cnt(:,1:2)];
IR_True(:,1:2) = cnt(:,1:2);

for counter = setdiff(1:15, 13) 
    [param_iter IR_ind counter]

% Set A-B test
i = cnt(counter,1);
j = cnt(counter,2);

what = WW(:,i);
f_hat = F_Hat(:,counter);
fa_hat = F_Hat_a(:,counter);
ahat = a_est(i);

a_AB = [a_est(i) , a_est(j)];
MI = [max(0,trapz(x,U(WW(:,i)).*fa_hat)) , max(0,trapz(x,U(WW(:,j)).*fa_hat))];
eps_AB = log(a_AB(2)./a_AB(1)) ./ log(MI(2)./MI(1));
beta_AB = log(a_AB(1)) - eps_AB.*log(MI(1));
c0_AB = exp(-beta_AB/eps_AB);
cost_AB = @(a) min(100, ((c0_AB./((1./eps_AB)+1)).*(a.^((1./eps_AB)+1))));

Data_AB(counter, 1:4, IR_ind) = [eps_AB , beta_AB , MI];

Profit_Est(counter,4) = trapz(x, (m.*x-what).*f_hat);

% For consistency, "true profit" and outside option is evaluated based on a_model
Profit_True(counter,4) = trapz(x, (m.*x-what).*F(:,a_model(i)));
IR_True(counter,3) = IR(i);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compute optimally perturbed contract

Da_max = -1./min(fa_hat./f_hat) - 1; Da_min = -1./max(fa_hat./f_hat) + 1;
a_TRGT = linspace(max(ahat+Da_min, 2000), min(ahat+Da_max, 2300),60);
a_TRGT_Rec(counter,:)=a_TRGT;

for k=1:length(a_TRGT)

Da = (a_TRGT(k) - ahat);
LL_Agent = ones(N,1).*U(magnify.*100);
RHS_IC = (((ahat+Da)./ahat).^(1/eps_AB)) .* trapz(x,U(what).*fa_hat);

cvx_begin quiet
variables V(N,1)
maximize( cc.*sum((m.*x - uinv(V)) .* (f_hat + Da.*fa_hat)) )
subject to
    cc.*sum(V.*fa_hat) >= RHS_IC; % Local IC constraint
    cc.*sum(V.*(f_hat + fa_hat.*Da)) - cost_AB(ahat+Da) >= IR_extrap(counter, IR_ind); % IR constraint
    V >= LL_Agent; % LL constraint
    V(2:end) >= V(1:end-1); % Monotonicity constraint
cvx_end 

w_pert(:,k) = uinv(V);
Profit_pert_Est(counter,k) = cvx_optval;
Cost_pert_Est(counter,k) = trapz(x, w_pert(:,k).*(f_hat + Da.*fa_hat));

% Computer "true" effort and profit corresponding to each adjusted contract
U_agent_pert = zeros(length(A),1);
for l = 1:length(A)
    U_agent_pert(l,1) = trapz(x,U_true(w_pert(:,k)) .* F(:,A(l))) - cost(A(l));
end
[maxU_pert indA] = max(U_agent_pert);
a_pert_true(counter,k) = A(indA);
a_pert_est(counter,k) = ahat + Da;
Profit_pert_True(counter,k) = trapz(x, (m.*x-w_pert(:,k)).*F(:,a_pert_true(counter,k)));

Cost_pert_True(counter,k) = trapz(x,w_pert(:,k).*F(:,a_pert_true(counter,k)));

end

% Find the effort that maximizes the firm's (estimated) profit
[maxProfit maxK] = max(Profit_pert_Est(counter,:));

w_Rec(:,:,counter) = w_pert;
w_Opt(:,counter, IR_ind) = w_pert(:,maxK);
Profit_Est(counter,5) = maxProfit; % Estimated Profit of optimal perturbation

a_Opt(counter,1) = a_TRGT(maxK); % Principal's target effort level
a_Opt(counter,2) = a_pert_true(counter,maxK); % True effort level based on estimated model
Profit_True(counter,5) = Profit_pert_True(counter,maxK); % True profit of "optimal" perturbation

IR_True(counter,4) = trapz(x,U_true(w_Opt(:,counter, IR_ind)).*F(:,a_Opt(counter,2))) - cost(a_Opt(counter,2)); % Agent's utility under optimal perturbation

Summary(counter,1:3) = [cnt(counter,1:2) IR_ind];
Summary(counter,4:7) = [Opt_a(param_cntr, IR_ind) a_Opt(counter,2) a_Opt(counter,1) a_model(cnt(counter,1))];
    % Fourth column is the optimal effort level
    % Fifth column is the effort she actually implements
    % Sixth column is what the effort the principal thinks she is implementing
    % Seventh column is the effort in the A-test
Summary(counter,9) = Profit_Base(IR_ind); % Profit of status quo contract giving agent utility IR_ind 

Summary(counter,11) = Profit_True(counter,4); % Profit of status quo contract
Summary(counter,12) = trapz(x, m.*x.*F(:,a_model(cnt(counter,1)))); % Revenue of status quo contract
Summary(counter,13) = trapz(x,WW(:,cnt(counter,1)).*F(:,a_model(cnt(counter,1)))); % Wage bill of status quo contract

Summary(counter,14) = Profit_True(counter,5); % Profit of optimal perturbation
Summary(counter,15) = trapz(x, m.*x.*F(:,a_Opt(counter,2))); % Revenue of optimal perturbation
Summary(counter,16) = trapz(x, w_Opt(:,counter, IR_ind).*F(:,a_Opt(counter,2))); % Cost of optimal perturbation

Summary(counter,17) = Cost_costmin(IR_ind, round(a_Opt(counter,2)/step)*step,param_cntr); % Min-cost contract implementing effort of optimal perturbation

Summary(counter,18) = IR_True(counter,4);
Summary(counter, 19) = IR(IR_ind);
Summary(counter,20) = OptProfit(param_cntr,IR_ind); % Profit of optimal contract
Summary(counter,21) = Cost_costmin(IR_ind, Opt_a(param_cntr, IR_ind),param_cntr); % Cost of optimal contract

Summary(counter,23) = Summary(counter,5) - Summary(counter,4); % Effort deviation
Summary(counter,24) = Summary(counter,16) - Summary(counter,17); % Overpayment
Summary(counter,25) = Summary(counter,14) - Summary(counter,9); % Gains of optimal adjustment
Summary(counter,26) = Summary(counter,20) - Summary(counter,9); % Max gains available

end

Summary_list(:,:,IR_ind,param_iter) = Summary;

end

if param_iter == 1 && magnify == 1

%%%%%%% Figure 7 %%%%%%%%%

figure('Name','Figure 7: Benchmark-optimal and test-optimal contracts using the homogeneous A/B tests for C=3 and C=7','NumberTitle','off', 'units','normalized','outerposition',[0 0 1 1])
set(0,'defaultTextInterpreter','latex');

subplot(1,2,1); plot([0:3500], Opt_W(:,3), 'k', 'LineWidth', 5); hold on
plot([0:3500], w_Opt(:,cnt_nonhybrid,3), 'LineWidth', 3);  hold off
xlabel('$x$','FontSize',32); ylabel('$w(x)$','FontSize',32)
title('$C=3$','FontSize',32) 

subplot(1,2,2); plot([0:3500], Opt_W(:,7), 'k', 'LineWidth', 5); hold on
plot([0:3500], w_Opt(:,cnt_nonhybrid,7), 'LineWidth', 3); hold off
xlabel('$x$','FontSize',32); ylabel('$w(x)$','FontSize',32) 
title('$C=7$','FontSize',32) 

legend('$w^*(w^C)$', '$w^{23}(w^C)$', '$w^{24}(w^C)$', '$w^{25}(w^C)$', '$w^{34}(w^C)$', '$w^{35}(w^C)$', '$w^{45}(w^C)$', '$w^{67}(w^C)$', 'FontSize',25,'Interpreter','latex','Location','northwest')
legend('boxoff')

fig = gcf;
fig.Color = 'w'; 

end

end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

for n=2:7
    Sum1(7*(n-2)+1:7*(n-1),:) = Summary_list(cnt_nonhybrid,:,n,1);
    Sum2(7*(n-2)+1:7*(n-1),:) = Summary_list(cnt_nonhybrid,:,n,2);
    Sum3(7*(n-2)+1:7*(n-1),:) = Summary_list(cnt_nonhybrid,:,n,3);
    Sum4(7*(n-2)+1:7*(n-1),:) = Summary_list(cnt_nonhybrid,:,n,4);
    Sum5(7*(n-2)+1:7*(n-1),:) = Summary_list(cnt_nonhybrid,:,n,5);
    Sum6(7*(n-2)+1:7*(n-1),:) = Summary_list(cnt_nonhybrid,:,n,6);
    Sum7(7*(n-2)+1:7*(n-1),:) = Summary_list(cnt_nonhybrid,:,n,7);    
end

cnt_hybrid([7])=[];
for n=2:7
    Sum1_h(7*(n-2)+1:7*(n-1),:) = Summary_list(cnt_hybrid,:,n,1);
    Sum2_h(7*(n-2)+1:7*(n-1),:) = Summary_list(cnt_hybrid,:,n,2);
    Sum3_h(7*(n-2)+1:7*(n-1),:) = Summary_list(cnt_hybrid,:,n,3);
    Sum4_h(7*(n-2)+1:7*(n-1),:) = Summary_list(cnt_hybrid,:,n,4);
    Sum5_h(7*(n-2)+1:7*(n-1),:) = Summary_list(cnt_hybrid,:,n,5);
    Sum6_h(7*(n-2)+1:7*(n-1),:) = Summary_list(cnt_hybrid,:,n,6);
    Sum7_h(7*(n-2)+1:7*(n-1),:) = Summary_list(cnt_hybrid,:,n,7);    
end

% Effort she actually implements - optimal effort
EffortDev = [mean(Sum1(:,23)) mean(Sum2(:,23)) mean(Sum3(:,23)) mean(Sum4(:,23)) mean(Sum5(:,23)) mean(Sum6(:,23)) mean(Sum7(:,23))];

% Average overpayments
Overpayments = [mean(Sum1(isfinite(Sum1(:,24)),24)) mean(Sum2(isfinite(Sum2(:,24)),24)) mean(Sum3(isfinite(Sum3(:,24)),24)) mean(Sum4(isfinite(Sum4(:,24)),24)) mean(Sum5(isfinite(Sum5(:,24)),24)) mean(Sum6(isfinite(Sum6(:,24)),24)) mean(Sum7(isfinite(Sum7(:,24)),24))];

% Gains Ratio
AvgGains = [mean(Sum1(:,25)) mean(Sum2(:,25)) mean(Sum3(:,25)) mean(Sum4(:,25)) mean(Sum5(:,25)) mean(Sum6(:,25)) mean(Sum7(:,25))];
MaxGains = [mean(Sum1(:,26)) mean(Sum2(:,26)) mean(Sum3(:,26)) mean(Sum4(:,26)) mean(Sum5(:,26)) mean(Sum6(:,26)) mean(Sum7(:,26))];
GainsRatio = 100.*AvgGains ./ MaxGains;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

EffortDev_h = [mean(Sum1_h(:,23)) mean(Sum2_h(:,23)) mean(Sum3_h(:,23)) mean(Sum4_h(:,23)) mean(Sum5_h(:,23)) mean(Sum6_h(:,23)) mean(Sum7_h(:,23))];
Overpayments_h = [mean(Sum1_h(:,24)) mean(Sum2_h(:,24)) mean(Sum3_h(:,24)) mean(Sum4_h(:,24)) mean(Sum5_h(:,24)) mean(Sum6_h(:,24)) mean(Sum7_h(:,24))];
AvgGains_h = [mean(Sum1_h(:,25)) mean(Sum2_h(:,25)) mean(Sum3_h(:,25)) mean(Sum4_h(:,25)) mean(Sum5_h(:,25)) mean(Sum6_h(:,25)) mean(Sum7_h(:,25))];
MaxGains_h = [mean(Sum1_h(:,26)) mean(Sum2_h(:,26)) mean(Sum3_h(:,26)) mean(Sum4_h(:,26)) mean(Sum5_h(:,26)) mean(Sum6_h(:,26)) mean(Sum7_h(:,26))];
GainsRatio_h = 100.*AvgGains_h ./ MaxGains_h;

ParametersList = ParamList;
Table_homogeneous = round([AvgGains ; MaxGains; GainsRatio ; EffortDev ; Overpayments],2);
Table_hybrid = round([AvgGains_h ; MaxGains_h; GainsRatio_h ; EffortDev_h ; Overpayments_h],2);

% Table 4 = [ParametersList ; Table_homogeneous]
% Table 5 = [ParametersList ; Table_hybrid]
% Table 6 = [ParametersList ; Table_homogeneous ; Table_hybrid]

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Sq2 = find(Sum1(:,3)==2);
Sq3 = find(Sum1(:,3)==3);
Sq4 = find(Sum1(:,3)==4);
Sq5 = find(Sum1(:,3)==5);
Sq6 = find(Sum1(:,3)==6);
Sq7 = find(Sum1(:,3)==7);

GainsAdj_xaxis = [Sum1(Sq2(1),26) ; Sum1(Sq3(1),26) ; Sum1(Sq4(1),26) ; Sum1(Sq5(1),26) ; Sum1(Sq6(1),26) ; Sum1(Sq7(1),26)];
GainsAdj_yaxis = [mean(Sum1(Sq2,25)) ; mean(Sum1(Sq3,25)) ; mean(Sum1(Sq4,25)) ; mean(Sum1(Sq5,25)) ; mean(Sum1(Sq6,25)) ; mean(Sum1(Sq7,25))];

EffortAdj_xaxis = [Sum1(Sq2(1),4) - a_model(2) ; Sum1(Sq3(1),4)  - a_model(3) ; Sum1(Sq4(1),4)  - a_model(4) ; Sum1(Sq5(1),4) -  a_model(5) ; Sum1(Sq6(1),4)  - a_model(6) ; Sum1(Sq7(1),4)  - a_model(7)];
EffortAdj_yaxis = [mean(Sum1(Sq2,5)) - a_model(2) ; mean(Sum1(Sq3,5)) - a_model(3) ; mean(Sum1(Sq4,5)) - a_model(4) ; mean(Sum1(Sq5,5)) - a_model(5) ; mean(Sum1(Sq6,5)) - a_model(6) ; mean(Sum1(Sq7,5)) - a_model(7) ];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if magnify == 1

%%%%%%% Figure 2 %%%%%%%%%
    
A = [ones(6,1) GainsAdj_xaxis];
b_reg =((A'*A)^-1)*A'*GainsAdj_yaxis;
range = [-10,40];

figure('Name','Figure 2: Average realized gains vs. Maximum available gains','NumberTitle','off','units','normalized','outerposition',[0 0 1 1])
set(0,'defaultTextInterpreter','latex');

plot(GainsAdj_xaxis, GainsAdj_yaxis, 'pb' ,'markerfacecolor','blue','MarkerSize',20, 'LineWidth',2); hold on
plot(range, range, '--r', 'LineWidth',4);
plot(range, b_reg(1) + b_reg(2).*range, '--g', 'LineWidth',2);
hold off
set(gca,'FontSize',20)
xlabel('Maximum Available Gains','FontSize',32); ylabel('Average Realized Gains','FontSize',32)

fig = gcf;
fig.Color = 'w';    
saveas(gcf,'../Figure2.png')

%%%%%%% Figure 3 %%%%%%%%%

range_effort = [min(min(EffortAdj_xaxis), min(EffortAdj_yaxis))-10 , max(max(EffortAdj_xaxis), max(EffortAdj_yaxis))+10];

figure('Name','Figure 3: Test-optimal effort change vs. benchmark-optimal effort change','NumberTitle','off','units','normalized','outerposition',[0 0 1 1])
set(0,'defaultTextInterpreter','latex');

plot(EffortAdj_xaxis, EffortAdj_yaxis, 'pb' ,'markerfacecolor','blue','MarkerSize',20, 'LineWidth',2); hold on
plot(range_effort, range_effort, '--r', 'LineWidth',4);
hold off
set(gca,'FontSize',20)
xlabel('Benchmark-optimal Effort Change','FontSize',32); ylabel('Test-optimal Effort Change','FontSize',32)
xlim(range_effort); ylim(range_effort);

fig = gcf;
fig.Color = 'w'; 
saveas(gcf,'../Figure3.png')
    
%%%%%%% Figure 6 %%%%%%%%%
    
figure('Name','Figure 6: Disaggregated data for homogeneous A/B Tests','NumberTitle','off','units','normalized','outerposition',[0 0 1 1])
set(0,'defaultTextInterpreter','latex');

subplot(2,1,1); 
plot(Sq2, Sum1(Sq2,26), 'k', Sq3, Sum1(Sq3,26), 'k', Sq4, Sum1(Sq4,26), 'k', Sq5, Sum1(Sq5,26), 'k', Sq6, Sum1(Sq6,26), 'k',Sq7, Sum1(Sq7,26), 'k', 'LineWidth',3)
hold on; plot(Sum1(:,25), 'bs', 'MarkerSize',10, 'MarkerFaceColor', 'b'); hold off
xticks([1:42])
xticklabels({'2-3','2-4','2-5','3-4','3-5','4-5','6-7','2-3','2-4','2-5','3-4','3-5','4-5','6-7','2-3','2-4','2-5','3-4','3-5','4-5','6-7','2-3','2-4','2-5','3-4','3-5','4-5','6-7','2-3','2-4','2-5','3-4','3-5','4-5','6-7','2-3','2-4','2-5','3-4','3-5','4-5','6-7','2-3','2-4','2-5','3-4','3-5','4-5','6-7'})
ylabel('Gains related to $w^C$','FontSize',25)
h=get(gca,'Children');
legend(h([1 7]), 'Realized Gains', 'Max. Available Gains', 'FontSize',25)
legend('boxoff')

pos = get(gca,'position'); 
pos_diff = pos(4) * 0.35; 
pos(4) = pos(4) + pos_diff; pos(2) = pos(2) - pos_diff; set(gca,'position',pos); 

subplot(2,1,2); 
b=bar(100.* (Sum1(:,18)./Sum1(:,19) - 1), 0.2, 'r', 'EdgeColor', [1 1 1]); 
b.FaceColor = 'flat';
b.CData(find((Sum1(:,18)./Sum1(:,19) - 1)>=0),:) = ones(length(find((Sum1(:,18)./Sum1(:,19) - 1)>=0)),1).*[0 0 1];
ylabel('$u(w^{AB}) / u(w^C)-1$','FontSize',25)

pos = get(gca,'position');  
pos_diff = -pos(4) * 0.25; 
pos(4) = pos(4) + pos_diff;
set(gca,'position',pos); 

fig = gcf;
fig.Color = 'w';  
saveas(gcf,'../Figure6.png')
    
elseif magnify == 100

%%%%%%% Figure 10 %%%%%%%%%

figure('Name','Figure 10: Disaggregated data for homogeneous A/B Tests when payoffs are scaled by 100','NumberTitle','off', 'units','normalized','outerposition',[0 0 1 1])
set(0,'defaultTextInterpreter','latex');

subplot(2,1,1); 
plot(Sq2, Sum6(Sq2,26), 'k', Sq3, Sum6(Sq3,26), 'k', Sq4, Sum6(Sq4,26), 'k', Sq5, Sum6(Sq5,26), 'k', Sq6, Sum6(Sq6,26), 'k',Sq7, Sum6(Sq7,26), 'k', 'LineWidth',3)
hold on; plot(Sum6(:,25), 'co', 'MarkerSize',5, 'MarkerFaceColor', 'b'); hold off
xticks([1:42])
xticklabels({'2-3','2-4','2-5','3-4','3-5','4-5','6-7','2-3','2-4','2-5','3-4','3-5','4-5','6-7','2-3','2-4','2-5','3-4','3-5','4-5','6-7','2-3','2-4','2-5','3-4','3-5','4-5','6-7','2-3','2-4','2-5','3-4','3-5','4-5','6-7','2-3','2-4','2-5','3-4','3-5','4-5','6-7','2-3','2-4','2-5','3-4','3-5','4-5','6-7'})
ylabel('Gains related to $w^C$','FontSize',25)
h=get(gca,'Children');
legend(h([1 7]), 'Realized Gains', 'Max. Available Gains', 'FontSize',25)
legend('boxoff')

pos = get(gca,'position'); 
pos_diff = pos(4) * 0.35; 
pos(4) = pos(4) + pos_diff; pos(2) = pos(2) - pos_diff; set(gca,'position',pos); 

subplot(2,1,2); 
b=bar(100.* (Sum6(:,18)./Sum6(:,19) - 1), 0.2, 'r', 'EdgeColor', [1 1 1]); 
b.FaceColor = 'flat';
b.CData(find((Sum6(:,18)./Sum6(:,19) - 1)>=0),:) = ones(length(find((Sum6(:,18)./Sum6(:,19) - 1)>=0)),1).*[0 0 1];
ylabel('$u(w^{AB}) / u(w^C)-1$','FontSize',25)

pos = get(gca,'position');  
pos_diff = -pos(4) * 0.25; 
pos(4) = pos(4) + pos_diff;
set(gca,'position',pos); 

fig = gcf;
fig.Color = 'w'; 
saveas(gcf,'../Figure10.png')
    
end