function [Table10] = OptAdjustments_ExtraWork(profit_margin, RRA_model, RRA_test)

load('DP_Data_ExtraWork')

rho_true = RRA_model;
rho_adj = RRA_test;
U_true = @(om) ( (om.^(1-rho_true)) / (1-rho_true) );
U_adj = @(om) ( (om.^(1-rho_adj)) / (1-rho_adj) );

m = profit_margin;

xx = linspace(0,20,21)';
alpha = [0 0.05 0.5 2 5];
WW = 100 + alpha.*xx;

% Avg. #Additional WWII cards completed
%%%%%%%%%%%%%%%%%%%%%%%

% Probability of completing extra 20 cards
A = [mean(DP_extra_alpha0c) mean(DP_extra_alpha01c) mean(DP_extra_alpha1c) mean(DP_extra_alpha4c) mean(DP_extra_alpha10c)];

[F_0c,x_0c] = ecdf(DP_extra_alpha0c);
[F_01c,x_01c] = ecdf(DP_extra_alpha01c);
[F_1c,x_1c] = ecdf(DP_extra_alpha1c);
[F_4c,x_4c] = ecdf(DP_extra_alpha4c);
[F_10c,x_10c] = ecdf(DP_extra_alpha10c);

beta_0c = [ones(length(F_0c)-2,1) x_0c(2:end-1)] \ F_0c(2:end-1); FF(:,1) = [beta_0c(1) + beta_0c(2).*xx(1:end-1) ; 1];
beta_01c = [ones(length(F_01c)-2,1) x_01c(2:end-1)] \ F_01c(2:end-1); FF(:,2) = [beta_01c(1) + beta_01c(2).*xx(1:end-1) ; 1];
beta_1c = [ones(length(F_1c)-2,1) x_1c(2:end-1)] \ F_1c(2:end-1); FF(:,3) = [beta_1c(1) + beta_1c(2).*xx(1:end-1) ; 1];
beta_4c = [ones(length(F_4c)-2,1) x_4c(2:end-1)] \ F_4c(2:end-1); FF(:,4) = [beta_4c(1) + beta_4c(2).*xx(1:end-1) ; 1];
beta_10c = [ones(length(F_10c)-2,1) x_10c(2:end-1)] \ F_10c(2:end-1); FF(:,5) = [beta_10c(1) + beta_10c(2).*xx(1:end-1) ; 1];

%FF = [interp1(x_0c(2:end), F_0c(2:end),xx) , interp1(x_01c(2:end), F_01c(2:end),xx) , interp1(x_1c(2:end), F_1c(2:end),xx), interp1(x_4c(2:end), F_4c(2:end),xx),  interp1(x_10c(2:end), F_10c(2:end),xx)];

for k = 1:5
    dF(:,k) = [FF(1,k) ; FF(2:end,k) - FF(1:end-1,k)];
end

%%%%%%%%%%%%%%%%%%%%%%%
% Construct benchmark model

A_true = linspace(0,20,201);

for x = 1:21
    dF_true(x,:) = spline(A, dF(x,:), A_true);
end
dF_a = dF_true(:,2:end) - dF_true(:,1:end-1);
rel_Aindex = find(min(dF_true)>=0);

for k=1:5
    MI_true(k) = sum(U_true(WW(:,k)) .* dF_a(:,round(10*A(k))));
end

G = @(bb) ( log(A) - bb(1) - bb(2).*log(max(0,MI_true + bb(3))) );
opts = optimoptions(@lsqnonlin,'MaxFunctionEvaluations',10^10, 'MaxIter',10^10,'TolX',10^-40, 'TolFun', 10^-15);
params = lsqnonlin(G, [3 ; 0.15 ; 10^-3],[],[],opts); % [beta, epsilon, I0]

C_true = @(a) ( (params(2)/(1+params(2))).*(exp(-params(1)/params(2))).*(a.^((1+params(2))/params(2))) - params(3).*a );

% IR constraints * Baseline profit
for k=1:5
    IR_true(k) = sum(U_true(WW(:,k)) .* dF_true(:,round(10*A(k)))) - C_true(A(k));
    Profit_base(k) = 100 + m.*sum(xx.*dF_true(:,round(10*A(k)))) - sum(WW(:,k).*dF_true(:,round(10*A(k))));
end

% Find optimal contract

Profit_costmin = -100 .* ones(length(A_true),5);

for IR = 2:5
    IR
    for ind = rel_Aindex
        
        %a_target = A_true(ind);
        
        cvx_begin quiet
            variables v(21,1)
            maximize( 100 + m.*sum(xx.*dF_true(:,ind)) - sum( (((1-rho_true).*v).^(1./(1-rho_true))) .* dF_true(:,ind) ) )
            subject to
                for ind_ic = rel_Aindex % IC constraint
                    sum(v.*dF_true(:,ind)) - C_true(A_true(ind)) >= sum(v.*dF_true(:,ind_ic)) - C_true(A_true(ind_ic));
                end
                sum(v.*dF_true(:,ind)) - C_true(A_true(ind)) >= IR_true(IR); % IR constraint
                v >= U_true(100); % LL constraint
                v(2:end) >= v(1:end-1); % Monotonicity constraint
        cvx_end
        
        if isreal(cvx_optval) && isfinite(cvx_optval)
            Profit_costmin(ind,IR) = cvx_optval;
            W_costmin(:, ind,IR) = (((1-rho_true).*v).^(1./(1-rho_true)));
            WageBill_costmin(ind,IR) = sum( (((1-rho_true).*v).^(1./(1-rho_true))) .* dF_true(:,ind) );
        end
        
    end
    
    [Opt_Profit(IR) Opt_indA(IR)] = max(Profit_costmin(:,IR));
    Opt_A(IR) = A_true(Opt_indA(IR));
    Opt_W(:,IR) = W_costmin(:,Opt_indA(IR),IR);
    Opt_IR(IR) = sum(U_true(Opt_W(:,IR)) .* dF_true(:,Opt_indA(IR))) - C_true(Opt_A(IR));
    
end

% Generate all pairs of A-B tests
NN=1;
for k=2:5
    for n = 2:length(A)-1
        for nn = n+1:length(A)
        	cnt(NN,:)=[n nn k];
            NN=NN+1;
        end
    end
end

for counter = 1:length(cnt)
    
    counter
    
% Set A-B test
i = cnt(counter,1);
j = cnt(counter,2);

h(:,counter) = (dF(:,i)-dF(:,j))./(A(i)-A(j));
g(:,counter) = dF(:,i) - A(i).*h(:,counter);

for k=2:length(A)
    MI(counter,k) = sum(U_adj(WW(:,k)) .* h(:,counter));
end

eps(counter) = log(A(i)./A(j)) ./ log((MI(counter,i))./(MI(counter,j)));
beta(counter) = log(A(i)) - eps(counter).*log(MI(counter,i));

Cost = @(a) ( (eps(counter)/(1+eps(counter))).*(exp(-beta(counter)/eps(counter))).*(a.^((1+eps(counter))/eps(counter))) );

for k=2:length(A)
    IR_ab(counter,k) = sum(U_adj(WW(:,k)) .* dF(:,k)) - Cost(A(k));
end

% Compute optimal adjustment

Profit_adj = -100 .* ones(length(A_true),length(cnt));

for ind = rel_Aindex
    
    a_target = A_true(ind);
    
    if min((g(:,counter)+a_target.*h(:,counter)))>=0
    
    cvx_begin quiet
    variables v(21,1)
    maximize( 100 + m.*a_target - sum( (((1-rho_adj).*v).^(1./(1-rho_adj))) .* (g(:,counter)+a_target.*h(:,counter)) ) )
    subject to
        sum(v.*h(:,counter)) >= exp(-beta(counter)/eps(counter)) * (a_target^(1/eps(counter)));
        sum(v.*(g(:,counter)+a_target.*h(:,counter))) - Cost(a_target) >= IR_ab(counter, cnt(counter,3));
        v >= U_adj(100);
        v(2:end) >= v(1:end-1);
    cvx_end
    
    if isreal(cvx_optval) && isfinite(cvx_optval)
    	Profit_adj(ind,counter) = cvx_optval;
    	W_adj(:, ind,counter) = (((1-rho_adj).*v).^(1./(1-rho_adj)));
    end
    
    end
        
    end
    
    [ans OptindA_adj(counter)] = max(Profit_adj(:,counter));
    OptA_adj(counter) = A_true(OptindA_adj(counter));
    OptW_adj(:,counter) = W_adj(:,OptindA_adj(counter),counter);
    
    % Compute True Effort & True Profit
    
    for ind = rel_Aindex
    
        a_test = A_true(ind);
        U_agent(ind,counter) = sum(U_true(OptW_adj(:,counter)).*dF_true(:,ind)) - C_true(a_test);
    end
    
    [IR_adj(counter) IndA_adj(counter)] = max(U_agent(:,counter));
    A_adj(counter) = A_true(IndA_adj(counter));
    OptProfit_adj(counter) = 100 + sum((m.*xx - OptW_adj(:,counter)).*dF_true(:,IndA_adj(counter)));
    WageBill_adj(counter) = sum(OptW_adj(:,counter).*dF_true(:,IndA_adj(counter)));

    Summary(counter,:) = [cnt(counter,:) -1 Profit_base(cnt(counter,3)) OptProfit_adj(counter) Opt_Profit(cnt(counter,3)) -1 IR_true(cnt(counter,3)) IR_adj(counter) Opt_IR(cnt(counter,3)) -1 A_adj(counter) Opt_A(cnt(counter,3)) -1 (WageBill_adj(counter)-WageBill_costmin(IndA_adj(counter),cnt(counter,3)))];
    
end

MaxGains = Summary(:,7) - Summary(:,5);
RealGains = Summary(:,6) - Summary(:,5);
GainsRatio = 100*mean(RealGains ./ MaxGains);
EffortDev = mean(A_adj-Opt_A(cnt(:,3)));
Overpayment = mean(Summary(:,16)); 

Table10 = [rho_true ; rho_adj ; m ; round(mean(RealGains),2) ; round(mean(MaxGains),2) ; round(GainsRatio,2) ; round(EffortDev,3) ; round(Overpayment,2)];

if profit_margin == 5 && RRA_model == 0.3 && RRA_test == 0.3

figure('Name','Figure 13: Disaggregated data of optimal adjustments for the WWII extra-work card coding task','NumberTitle','off','units','normalized','outerposition',[0 0 1 1])
set(0,'defaultTextInterpreter','latex');

subplot(2,1,1); %set(s1, 'OuterPosition', [0,0.5, 1, 0.4]);
plot([1:6], MaxGains(1:6), 'k', [7:12], MaxGains(7:12), 'k', [13:18], MaxGains(13:18), 'k', [19:24], MaxGains(19:24), 'k', 'LineWidth',3)
hold on; plot([1:24], RealGains, 'bs', 'MarkerSize',15, 'MarkerFaceColor', 'b'); hold off
xticks([1:24])
xticklabels({'2-3','2-4','2-5','3-4','3-5','4-5','2-3','2-4','2-5','3-4','3-5','4-5','2-3','2-4','2-5','3-4','3-5','4-5','2-3','2-4','2-5','3-4','3-5','4-5'})
h=get(gca,'Children');
legend(h([1 5])); legend('boxoff');

pos = get(gca,'position'); 
pos_diff = pos(4) * 0.35; 
pos(4) = pos(4) + pos_diff; pos(2) = pos(2) - pos_diff; set(gca,'position',pos); 

subplot(2,1,2); b=bar(100.* (Summary(:,10)./Summary(:,9)-1) , 0.1, 'r', 'EdgeColor', [1 1 1]); 
b.FaceColor = 'flat';
b.CData(find((Summary(:,10)./Summary(:,9)-1)>=0),:) = ones(length(find((Summary(:,10)./Summary(:,9)-1)>=0)),1).*[0 0 1];

pos = get(gca,'position');  
pos_diff = -pos(4) * 0.25; 
pos(4) = pos(4) + pos_diff;
set(gca,'position',pos); 

fig = gcf;
fig.Color = 'w';  
saveas(gcf,'../Figure13.png')

end