function [Table_out] = Predict_ABC(risk);

% Computes the performance of the prediction algorithm for A-B tests
% comprising w1, the "no-incentives" treatment as a function of I

load('DP_Data')
% Data is taken from DellaVigna and Pope. Based on their quote "it is
% physically impossible to score more than 3,500 points", I eliminated all
% entries with more than 3,500 points.

% Can estimate distributions using custom estimator (KernelEst.m) or
% Matlab's estimator (ksdensity). Results are similar.
[f_0c x] = KernelEst(DP_0c);
[f_01c x] = KernelEst(DP_01c);
[f_1c x] = KernelEst(DP_1c);
[f_4c x] = KernelEst(DP_4c);
[f_10c x] = KernelEst(DP_10c);
[f_40c x] = KernelEst(DP_40c);
[f_80c x] = KernelEst(DP_80c);

k = 3; %Epanechnikov = 1 ; Biweight = 2 ; Triweight = 3 ; Gaussian = 4 (2nd degree)
f_0c = f_0c(:,k) ./trapz(x,f_0c(:,k));
f_01c = f_01c(:,k) ./trapz(x,f_01c(:,k));
f_1c = f_1c(:,k) ./trapz(x,f_1c(:,k));
f_4c = f_4c(:,k) ./trapz(x,f_4c(:,k));
f_10c = f_10c(:,k) ./trapz(x,f_10c(:,k));
f_40c = f_40c(:,k) ./trapz(x,f_40c(:,k));
f_80c = f_80c(:,k) ./trapz(x,f_80c(:,k));

a_est = round([mean(DP_0c) mean(DP_01c) mean(DP_1c) mean(DP_4c) mean(DP_10c) mean(DP_40c) mean(DP_80c)]);
wLin = @(xx,alpha) (100+alpha.*xx);
wBonus = @(xx,B) (100 + B.*(xx>2000));

FF = [f_0c f_01c  f_1c f_4c f_10c f_40c f_80c];
WW = [wLin(x,0) wLin(x,0.001) wLin(x,0.01) wLin(x,0.04) wLin(x,0.1) wBonus(x,40) wBonus(x,80)];

cc = (max(x)-min(x))/length(x);

rho = risk; 
U = @(om) ( (om.^(1-rho)) / (1-rho) );
%U = @(om) (log(om));

% Generate all pairs of A-B tests comprising w1
NN=1;
for i=1:5
    for j=i+1:6
        for k=j+1:7
            cnt(NN,:)=[i j k];
            NN=NN+1;
        end
    end
end

line = 1;
for counter = 1:length(cnt)

i = cnt(counter,1);
j = cnt(counter,2);
k = cnt(counter,3);
ABC = [i j k];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Construct f(x|a)

A = [1:2300]';
F = zeros(length(x), length(A));
F_a = zeros(length(x), length(A));
 
for xx=1:length(x) 
    bb = [ones(3,1) a_est(ABC)'] \ FF(xx,ABC)';   
    %bb = [ones(2,1) a_est(ABC(2:3))'] \ FF(xx,ABC(2:3))';  % Constructs F_a based on treatments j and k only
    F(xx,1500:end) = bb(1) + bb(2).*A(1500:end);
end

F_a(:,1501:end) = F(:, 1501:end) - F(:, 1500:end-1);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Estimate parameters

for l=1:3
    MI(l) = max(0, trapz(x,U(WW(:,ABC(l))).*F_a(:,a_est(ABC(l)))));
end

I0(counter) = (fsolve(@(I) (log(a_est(i)./a_est(j)) ./ log((MI(1)+(I.^2))./(MI(2)+(I.^2))))-(log(a_est(i)./a_est(k)) ./ log((MI(1)+(I.^2))./(MI(3)+(I.^2)))), 0.0001)).^2;
beta(counter) = log(a_est(i)) - (log(a_est(i)./a_est(j))) .* ( log(MI(1)+I0(counter)) ./ log((MI(1)+I0(counter))./(MI(2)+I0(counter))) );
eps(counter) = (log(a_est(i)./a_est(j))) ./ log((MI(1)+I0(counter))./(MI(2)+I0(counter)));
p(counter) = 1/eps(counter);

G = @(I0) (log(a_est(i)./a_est(j)) ./ log((MI(1)+I0)./(MI(2)+I0)))-(log(a_est(i)./a_est(k)) ./ log((MI(1)+I0)./(MI(3)+I0)));
a_pp = exp(beta(counter)).*((MI+I0(counter)).^eps(counter));

cost = @(a) (((exp(-beta(counter)./eps(counter)))./(p(counter)+1)).*(a.^(p(counter)+1)) - I0(counter).*a);
cp = @(a) ( (exp(-beta(counter)./eps(counter))).*(a.^p(counter)) - I0(counter) );

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Predict Effort
pred = [1:7]; pred([i j k])=[];
if pred(1) >= 2

for l=pred
        MM(l) = trapz(x,U(WW(:,l)).*F_a(:,a_est(i)));
        a_hat(i,j,k,l) = exp(beta(counter)).*((MM(l)+I0(counter)).^eps(counter));
        APE(i,j,k,l) = 100.* abs(a_hat(i,j,k,l)-a_est(l))/a_est(l); % Compute corresponding APE
        Table(line,:) = [i j k l a_hat(i,j,k,l) a_est(l) APE(i,j,k,l) beta(counter) eps(counter) I0(counter)]; %Each row lists i, j, k, predicted effort, true effort, and APE
        line=line+1;
end

end

end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Hom_within = find( ((Table(:,3)<=5) .* (Table(:,4) <= 5)) == 1 );
Hom_across = find( ((Table(:,3)<=5) .* (Table(:,4) >= 6)) == 1 );
Hybrid_pr = find( ((Table(:,3) >= 6) .* (Table(:,4) <= 5)) == 1 );
Hybrid_bonus = find( ((Table(:,3) >= 6) .* (Table(:,4) >= 6)) == 1 );
AB_incl0 = find( Table(:,1) == 1);
Hom = find( Table(:,3) <= 5 );
Hybrid = find( Table(:,3) >= 6 );

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
plotfig = 0;

if plotfig == 1

figure('units','normalized','outerposition',[0 0 1 1])
set(0,'defaultTextInterpreter','latex');
hold on
plot(Table(Hom_within, 6), Table(Hom_within, 5), 'rp','markerfacecolor','red','MarkerSize',15)
plot(Table(Hom_across, 6), Table(Hom_across, 5), 'b^','markerfacecolor','blue','MarkerSize',15)
plot(Table(Hybrid_pr, 6), Table(Hybrid_pr, 5), 'go','markerfacecolor','green','MarkerSize',10)
plot(Table(Hybrid_bonus, 6), Table(Hybrid_bonus, 5), 'ch','markerfacecolor','cyan','MarkerSize',15)
%plot(Table(AB_incl0, 6), Table(AB_incl0, 5), 'ms','markerfacecolor','magenta','MarkerSize',7)
diag = [1800 2200]; plot(diag,diag,'--k','linewidth',3)
hold off
set(gca,'FontSize',20)
xlabel('True Effort','FontSize',32); ylabel('Predicted Effort','FontSize',32);
legend('Homogeneous Tests (Piece-rate predictions)', 'Homogeneous Tests (Bonus predictions)', 'Hybrid Tests (Piece-rate predictions)','Hybrid Tests (Bonus predictions)','interpreter','latex','Location','northwest','FontSize',30);
legend('boxoff')
fig = gcf;
fig.Color = 'w';

end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Table_out = [corr(Table(Hom,5), Table(Hom, 6)) ; mean(Table(Hom, 7)) ; mean(Table(Hom_within, 7)) ; -1 ; mean(Table(Hom_across, 7)) ; max(Table(Hom, 7)) ; max(Table(Hom_within, 7)) ; -1 ; max(Table(Hom_across, 7)) ; -1 ; -1 ; corr(Table(Hybrid,5), Table(Hybrid, 6)) ; mean(Table(Hybrid, 7)) ; max(Table(Hybrid, 7))]; 