function [Table2] = Predict_Performance(risk, fig)

plotfig = fig;
load('DP_Data')
% Data is taken from DellaVigna and Pope. Based on their quote "it is
% physically impossible to score more than 3,500 points", I eliminated all
% entries with more than 3,500 points.

% Can estimate distributions using custom estimator (KernelEst.m) or
% Matlab's estimator (ksdensity). Results are similar.
[f_0c x] = KernelEst(DP_0c);
[f_01c x] = KernelEst(DP_01c);
[f_1c x] = KernelEst(DP_1c);
[f_4c x] = KernelEst(DP_4c);
[f_10c x] = KernelEst(DP_10c);
[f_40c x] = KernelEst(DP_40c);
[f_80c x] = KernelEst(DP_80c);

k = 3; %Epanechnikov = 1 ; Biweight = 2 ; Triweight = 3 ; Gaussian = 4 (2nd degree)
f_0c = f_0c(:,k) ./trapz(x,f_0c(:,k));
f_01c = f_01c(:,k) ./trapz(x,f_01c(:,k));
f_1c = f_1c(:,k) ./trapz(x,f_1c(:,k));
f_4c = f_4c(:,k) ./trapz(x,f_4c(:,k));
f_10c = f_10c(:,k) ./trapz(x,f_10c(:,k));
f_40c = f_40c(:,k) ./trapz(x,f_40c(:,k));
f_80c = f_80c(:,k) ./trapz(x,f_80c(:,k));

A = [mean(DP_01c) mean(DP_1c) mean(DP_4c) mean(DP_10c) mean(DP_40c) mean(DP_80c)];
wLin = @(xx,alpha) (100+alpha.*xx);
wBonus = @(xx,B) (100 + B.*(xx>2000));

FF = [f_01c f_1c f_4c f_10c f_40c f_80c];
%A = [trapz(x,x.*FF(:,1)) trapz(x,x.*FF(:,2)) trapz(x,x.*FF(:,3)) trapz(x,x.*FF(:,4)) trapz(x,x.*FF(:,5)) trapz(x,x.*FF(:,6))];
WW = [wLin(x,0.001) wLin(x,0.01) wLin(x,0.04) wLin(x,0.1) wBonus(x,40) wBonus(x,80)];

Nsize = [length(DP_0c)  length(DP_01c) length(DP_1c) length(DP_4c) length(DP_10c) length(DP_40c) length(DP_80c)];  
DPdata = zeros(max(Nsize),7);
DPdata(1:Nsize(1),1) = DP_0c; DPdata(1:Nsize(2),2) = DP_01c; DPdata(1:Nsize(3),3) = DP_1c;
DPdata(1:Nsize(4),4) = DP_4c; DPdata(1:Nsize(5),5) = DP_10c; DPdata(1:Nsize(6),6) = DP_40c; DPdata(1:Nsize(7),7) = DP_80c;  

rho = risk; 

if rho < 1
    U = @(om) ( (om.^(1-rho)) / (1-rho) );
elseif rho == 1
    U = @(om) (log(om));
end 

% Generate all pairs of A-B tests
NN=1;
for n=1:length(A)-1
    for nn=n+1:length(A)
        cnt(NN,:)=[n nn];
    NN=NN+1;
    end
end
cnt(13,:)=[];

line=1;
for counter=1:length(cnt)
    
% Set A-B test
i = cnt(counter,1);
j = cnt(counter,2);

wA = WW(:,i);
wB = WW(:,j);

f_hat = FF(:,i);
Da = A(j)-A(i);
f_a(:,counter) = (FF(:,j) - FF(:,i)) / (A(j)-A(i));  

for k=1:length(A)
    MI(counter,k) = max(0, trapz(x,U(WW(:,k)).*f_a(:,counter)));
end

eps(counter) = log(A(i)./A(j)) ./ log((MI(counter,i))./(MI(counter,j)));
beta(counter) = log(A(i)) - eps(counter).*log(MI(counter,i));

pred = [1:6]; pred([i j])=[];
for k = pred
        
    a_hat(i,j,k) = exp(beta(counter) + eps(counter).*log(MI(counter,k))); %Predict treatment k using A-B test comprising i & j
    APE(i,j,k) = 100.* abs(a_hat(i,j,k)-A(k))/A(k); % Compute corresponding APE
    Table(line,:) = [i+1 j+1 k+1 a_hat(i,j,k) A(k) APE(i,j,k)]; %Each row lists i, j, k, predicted effort, true effort, and APE
    
    f_predict(:,1,line) = FF(:,i) + (a_hat(i,j,k)-A(i)).*f_a(:,counter);
    f_predict(:,2,line) = FF(:,k);    
    
    line=line+1;

end

end

count_lin_lin = 1;
count_lin_bonus = 1;
count_bonus_lin = 1;
count_hybrid_lin = 1;
count_hybrid_bonus = 1;
for line=1:length(Table)
    if Table(line,1) <= 5 && Table(line,2) <= 5 && Table(line,3) <= 5 % Linear A-B tests predicting linear contract
        AB_lin_lin(count_lin_lin,:) = Table(line,:);
        count_lin_lin = count_lin_lin+1;
    elseif Table(line,1) <= 5 && Table(line,2) <= 5 && Table(line,3) >= 6 % Linear A-B tests predicting bonus contract
        AB_lin_bonus(count_lin_bonus,:) = Table(line,:);
        count_lin_bonus = count_lin_bonus+1;
    elseif Table(line,1) >= 6 && Table(line,2) >= 6 && Table(line,3) <= 5 % Bonus A-B test predicting linear contract
        AB_bonus_lin(count_bonus_lin,:) = Table(line,:);
        count_bonus_lin = count_bonus_lin+1;
    elseif ((Table(line,1) >= 6 && Table(line,2) <= 5) || (Table(line,1) <= 5 && Table(line,2) >= 6)) && Table(line,3) <= 5
        % Hybrid A-B tests predicting linear contract
        AB_hybrid_lin(count_hybrid_lin,:) = Table(line,:);
        count_hybrid_lin = count_hybrid_lin+1;
    else % Hybrid A-B tests predicting bonus contract
        AB_hybrid_bonus(count_hybrid_bonus,:) = Table(line,:);
        count_hybrid_bonus = count_hybrid_bonus+1;
    end
end
% Homogeneous tests are the first three

Corr_lin_lin = corrcoef(AB_lin_lin(:,4),AB_lin_lin(:,5)); Corr_lin_lin=Corr_lin_lin(2,1);
Corr_lin_bonus = corrcoef(AB_lin_bonus(:,4),AB_lin_bonus(:,5)); Corr_lin_bonus=Corr_lin_bonus(2,1);
Corr_bonus_lin = corrcoef(AB_bonus_lin(:,4),AB_bonus_lin(:,5)); Corr_bonus_lin=Corr_bonus_lin(2,1);
Corr_hybrid_lin = corrcoef(AB_hybrid_lin(:,4),AB_hybrid_lin(:,5)); Corr_hybrid_lin=Corr_hybrid_lin(2,1);
Corr_hybrid_bonus = corrcoef(AB_hybrid_bonus(:,4),AB_hybrid_bonus(:,5)); Corr_hybrid_bonus=Corr_hybrid_bonus(2,1);

%%%%%%%%%

Correlation_nonhybrid = corrcoef([AB_lin_lin(:,4) ; AB_lin_bonus(:,4) ; AB_bonus_lin(:,4)],[AB_lin_lin(:,5) ; AB_lin_bonus(:,5) ; AB_bonus_lin(:,5)]); Correlation_nonhybrid=Correlation_nonhybrid(2,1);
MAPE_nonhybrid = mean([AB_lin_lin(:,6) ; AB_lin_bonus(:,6) ; AB_bonus_lin(:,6)]);
MAPE_within = mean(AB_lin_lin(:,6));
MAPE_across_bonus = mean(AB_lin_bonus(:,6));
MAPE_across_lin = mean(AB_bonus_lin(:,6));
WorstCaseAPE_nonhybrid = max([AB_lin_lin(:,6) ; AB_lin_bonus(:,6) ; AB_bonus_lin(:,6)]);
WorstCaseAPE_within = max(AB_lin_lin(:,6));
WorstCaseAPE_across_bonus = max(AB_lin_bonus(:,6)); 
WorstCaseAPE_across_lin = max(AB_bonus_lin(:,6));

Correlation_hybrid = corrcoef([AB_hybrid_lin(:,4) ; AB_hybrid_bonus(:,4)],[AB_hybrid_lin(:,5) ; AB_hybrid_bonus(:,5)]); Correlation_hybrid=Correlation_hybrid(2,1);
MAPE_hybrid = mean([AB_hybrid_lin(:,6) ; AB_hybrid_bonus(:,6)]);
WorstCaseAPE_hybrid = max([AB_hybrid_lin(:,6) ; AB_hybrid_bonus(:,6)]);

% CV of estimates for non-hybrid tests
for k=1:4
    treat(:,k) = find( (Table(:,3)==k+1) .* min(1, (Table(:,2)<=5) + (Table(:,1)>=6)) == 1);
    CV_estimates(k) = 100.* std(Table(treat(:,k),4)) ./ mean(Table(treat(:,k),4));
end
for k=5:6
    treat6 = find( (Table(:,3)==k+1) .* min(1, (Table(:,2)<=5) + (Table(:,1)>=6)) == 1);
    CV_estimates(k) = 100.* std(Table(treat6,4)) ./ mean(Table(treat6,4));
end

for k=1:6
    treat_h = find( (Table(:,3)==k+1) .* (Table(:,1)<=5) .* (Table(:,2)>=6) == 1);
    CV_estimates_h(k) = 100.* std(Table(treat_h,4)) ./ mean(Table(treat_h,4));
end

Table2 = [Correlation_nonhybrid ; MAPE_nonhybrid ; MAPE_within ; MAPE_across_lin ; MAPE_across_bonus ; WorstCaseAPE_nonhybrid ; WorstCaseAPE_within ; WorstCaseAPE_across_lin ; WorstCaseAPE_across_bonus ; mean(CV_estimates) ; -1 ; -1 ; Correlation_hybrid ; MAPE_hybrid ; WorstCaseAPE_hybrid ; mean(CV_estimates_h)];

%%%%%%%%% Generate CDFs

x_bar = [1500 2000 2500];
for line = 1:56
        for y = 1:3500
            F_predict(y+1, 1,line) = trapz(x(1:y+1), max(0,f_predict(1:y+1,1,line))); %sum(f_predict(1:y,1,line)); % predicted CDF
            F_predict(y+1, 3,line) = trapz(x(1:y+1), f_predict(1:y+1,2,line)); % sum(f_predict(1:y,2,line)); % true CDF
        end
        [f xf]=ecdf(DPdata(1:Nsize(Table(line,3)), Table(line,3)));
        F_predict(:,2,line) = interp1(xf(2:end),f(2:end),x);
        
        Table_F_predict(line,:) = [1-F_predict(x_bar(1),1,line) 1-F_predict(x_bar(1),2,line) , 0 , -1 , 1-F_predict(x_bar(2),1,line) 1-F_predict(x_bar(2),2,line) , 0 , -1 , 1-F_predict(x_bar(3),1,line) 1-F_predict(x_bar(3),2,line) , 0];
        
        % KS Test p-value
        if plotfig >= 3
        [hyp,p_val] = kstest(DPdata(1:Nsize(Table(line,3)), Table(line,3)), 'Alpha', 0.05, 'CDF', [x F_predict(:, 1,line)]);
        Table(line, 7) = p_val;
        Table(line, 8) = hyp;
        end
        
end
Table_F_predict(:,3) = 100.*abs((Table_F_predict(:,1) ./ Table_F_predict(:,2))-1);
Table_F_predict(:,7) = 100.*abs((Table_F_predict(:,5) ./ Table_F_predict(:,6))-1);
Table_F_predict(:,11) = 100.*abs((Table_F_predict(:,9) ./ Table_F_predict(:,10))-1);

%%%%%%%%% Generate Figure 

%[B MAPE_nonhybrid MAPE_hybrid]

if plotfig == 1

figure('Name','Figure 1: Predicted vs. Actual Performance','NumberTitle','off','units','normalized','outerposition',[0 0 1 1])
set(0,'defaultTextInterpreter','latex');
hold on; 
plot(AB_lin_lin(:,5),AB_lin_lin(:,4),'rp','markerfacecolor','red','MarkerSize',20)
plot(AB_lin_bonus(:,5),AB_lin_bonus(:,4),'b^','markerfacecolor','blue','MarkerSize',10)
plot(AB_bonus_lin(:,5),AB_bonus_lin(:,4),'go','markerfacecolor','green','MarkerSize',15)
%plot([AB_hybrid_lin(:,5) ; AB_hybrid_bonus(:,5)], [AB_hybrid_lin(:,4) ; AB_hybrid_bonus(:,4)],'ks','markerfacecolor','black','MarkerSize',10)
%plot(AB_hybrid_bonus(:,5),AB_hybrid_bonus(:,4),'rp','markerfacecolor','red','MarkerSize',20)
diag = [1850 A(end)]; plot(diag,diag,'--k','linewidth',3)
hold off
set(gca,'FontSize',20)
xlabel('True Performance $(a_C)$','FontSize',32); ylabel('Predicted Performance $(\widehat{a}^{AB}_C)$','FontSize',32);
%title('Predictions using Homogeneous A/B Tests','FontSize',30,'FontWeight','normal')
legend('Within class (Piece-rate A/B tests)', 'Across class (Piece-rate A/B tests)', 'Across class (Bonus A/B test)','interpreter','latex','Location','northwest','FontSize',30);
%title('Predictions using Hybrid A/B Tests','FontSize',30,'FontWeight','normal')
%legend('Piece-rate treatments (Hybrid A/B tests)', 'Bonus treatments (Hybrid A/B tests)', 'Across class (Bonus A/B test)','interpreter','latex','Location','northwest','FontSize',30);
legend('boxoff')
fig = gcf;
fig.Color = 'w';
saveas(gcf,'../Figure1.png')

elseif plotfig == 2

plotcdf = [6 22 7 31];
figure('units','normalized','outerposition',[0 0 1 1])
set(0,'defaultTextInterpreter','latex');
    
for panel = 1:4

    subplot(2,2,panel); plot(x, F_predict(:,:,plotcdf(panel)), 'linewidth',3);
    xlabel('$x$','FontSize',20); ylabel('$F(x|a)$','FontSize',20);
    legend('True F(x)', 'Predicted F(x)','interpreter','latex','Location','northwest','FontSize',20);
    title(['A/B test comprising treatments ', num2str(Table(plotcdf(panel),1)), ' and ', num2str(Table(plotcdf(panel),2)),  ', used to predict output in treatment ', num2str(Table(plotcdf(panel),3))],'FontSize',20);
    legend('boxoff')

end

fig = gcf;
fig.Color = 'w';

elseif plotfig == 3

homo2 = ( find(((Table(:,1) <=5).*(Table(:,2)<=5)+(Table(:,1) >=6).*(Table(:,2)>=6)).*(Table(:,3)==2)));
homo3 = ( find(((Table(:,1) <=5).*(Table(:,2)<=5)+(Table(:,1) >=6).*(Table(:,2)>=6)).*(Table(:,3)==3)));
homo4 = ( find(((Table(:,1) <=5).*(Table(:,2)<=5)+(Table(:,1) >=6).*(Table(:,2)>=6)).*(Table(:,3)==4)));
homo5 = ( find(((Table(:,1) <=5).*(Table(:,2)<=5)+(Table(:,1) >=6).*(Table(:,2)>=6)).*(Table(:,3)==5)));
 
figure('Name','Figure 8: Predicted vs. actual CDF for piece-rate treatments','NumberTitle','off','units','normalized','outerposition',[0 0 1 1])
set(0,'defaultTextInterpreter','latex');
    
subplot(2,2,1); plot(x,[F_predict(:,2,homo2(1)) F_predict(:,1,homo2(1)) F_predict(:,1,homo2(2)) F_predict(:,1,homo2(3)) F_predict(:,1,homo2(4))], 'linewidth',3) 
legend(['$F_2(x)$'], ['$\widehat{F}_{2}^{34}$  [', num2str(round(Table(homo2(1),7),3)), ']'], ['$\widehat{F}_{2}^{35}$  [', num2str(round(Table(homo2(2),7),3)), ']'], ['$\widehat{F}_{2}^{45}$  [', num2str(round(Table(homo2(3),7),3)), ']'], ['$\widehat{F}_{2}^{67}$  [', num2str(round(Table(homo2(4),7),3)), ']'],'interpreter','latex','Location','northwest','FontSize',20); legend('boxoff')
xlabel('$x$','FontSize',30);

subplot(2,2,2); plot(x,[F_predict(:,2,homo3(1)) F_predict(:,1,homo3(1)) F_predict(:,1,homo3(2)) F_predict(:,1,homo3(3)) F_predict(:,1,homo3(4))], 'linewidth',3) 
legend(['$F_3(x)$'], ['$\widehat{F}_{3}^{24}$  [', num2str(round(Table(homo3(1),7),3)), ']'], ['$\widehat{F}_{3}^{25}$  [', num2str(round(Table(homo3(2),7),3)), ']'], ['$\widehat{F}_{3}^{45}$  [', num2str(round(Table(homo3(3),7),3)), ']'], ['$\widehat{F}_{3}^{67}$  [', num2str(round(Table(homo3(4),7),3)), ']'],'interpreter','latex','Location','northwest','FontSize',20); legend('boxoff')
xlabel('$x$','FontSize',30);

subplot(2,2,3); plot(x,[F_predict(:,2,homo4(1)) F_predict(:,1,homo4(1)) F_predict(:,1,homo4(2)) F_predict(:,1,homo4(3)) F_predict(:,1,homo4(4))], 'linewidth',3) 
legend(['$F_4(x)$'], ['$\widehat{F}_{4}^{23}$  [', num2str(round(Table(homo4(1),7),3)), ']'], ['$\widehat{F}_{4}^{25}$  [', num2str(round(Table(homo4(2),7),3)), ']'], ['$\widehat{F}_{4}^{35}$  [', num2str(round(Table(homo4(3),7),3)), ']'], ['$\widehat{F}_{4}^{67}$  [', num2str(round(Table(homo4(4),7),3)), ']'],'interpreter','latex','Location','northwest','FontSize',20); legend('boxoff')
xlabel('$x$','FontSize',30);

subplot(2,2,4); plot(x,[F_predict(:,2,homo5(1)) F_predict(:,1,homo5(1)) F_predict(:,1,homo5(2)) F_predict(:,1,homo5(3)) F_predict(:,1,homo5(4))], 'linewidth',3) 
legend(['$F_5(x)$'], ['$\widehat{F}_{5}^{23}$  [', num2str(round(Table(homo5(1),7),3)), ']'], ['$\widehat{F}_{5}^{24}$  [', num2str(round(Table(homo5(2),7),3)), ']'], ['$\widehat{F}_{5}^{34}$  [', num2str(round(Table(homo5(3),7),3)), ']'], ['$\widehat{F}_{5}^{67}$  [', num2str(round(Table(homo5(4),7),3)), ']'],'interpreter','latex','Location','northwest','FontSize',20); legend('boxoff')
xlabel('$x$','FontSize',30);

fig = gcf;
fig.Color = 'w';
saveas(gcf,'../Figure8.png')

elseif plotfig == 4
 
homo6 = ( find(((Table(:,1) <=5).*(Table(:,2)<=5)+(Table(:,1) >=6).*(Table(:,2)>=6)).*(Table(:,3)==6)));
homo7 = ( find(((Table(:,1) <=5).*(Table(:,2)<=5)+(Table(:,1) >=6).*(Table(:,2)>=6)).*(Table(:,3)==7)));    
    
figure('Name','Figure 9: Predicted vs. actual CDF for bonus treatments','NumberTitle','off','units','normalized','outerposition',[0 0 1 1])
set(0,'defaultTextInterpreter','latex');
    
subplot(1,2,1); plot(x,[F_predict(:,2,homo6(1)) F_predict(:,1,homo6(1)) F_predict(:,1,homo6(2)) F_predict(:,1,homo6(3)) F_predict(:,1,homo6(4)) F_predict(:,1,homo6(5)) F_predict(:,1,homo6(6))], 'linewidth',3) 
legend('$F_6(x)$', ['$\widehat{F}_{6}^{23}(x)$ [', num2str(round(Table(homo6(1),7),3)), ']'], ['$\widehat{F}_{6}^{24}(x)$ [', num2str(round(Table(homo6(2),7),3)), ']'], ['$\widehat{F}_{6}^{25}(x)$ [', num2str(round(Table(homo6(3),7),3)), ']'], ['$\widehat{F}_{6}^{34}(x)$ [', num2str(round(Table(homo6(4),7),3)), ']'], ['$\widehat{F}_{6}^{35}(x)$ [', num2str(round(Table(homo6(5),7),3)), ']'], ['$\widehat{F}_{6}^{45}(x)$ [', num2str(round(Table(homo6(6),7),3)), ']'],'interpreter','latex','Location','northwest','FontSize',20); legend('boxoff')
xlabel('$x$','FontSize',30);

subplot(1,2,2); plot(x,[F_predict(:,2,homo7(1)) F_predict(:,1,homo7(1)) F_predict(:,1,homo7(2)) F_predict(:,1,homo7(3)) F_predict(:,1,homo7(4)) F_predict(:,1,homo7(5)) F_predict(:,1,homo7(6))], 'linewidth',3) 
legend('$F_7(x)$', ['$\widehat{F}_{7}^{23}(x)$[', num2str(round(Table(homo7(1),7),3)), ']'], ['$\widehat{F}_{7}^{24}(x)$[', num2str(round(Table(homo7(2),7),3)), ']'], ['$\widehat{F}_{7}^{25}(x)$[', num2str(round(Table(homo7(3),7),3)), ']'], ['$\widehat{F}_{7}^{34}(x)$[', num2str(round(Table(homo7(4),7),3)), ']'], ['$\widehat{F}_{7}^{35}(x)$[', num2str(round(Table(homo7(5),7),3)), ']'], ['$\widehat{F}_{7}^{45}(x)$[', num2str(round(Table(homo7(6),7),3)), ']'],'interpreter','latex','Location','northwest','FontSize',20); legend('boxoff')
xlabel('$x$','FontSize',30);

fig = gcf;
fig.Color = 'w';
saveas(gcf,'../Figure9.png')

end
