function [Summary] = Predict_Performance_ExtraWork(risk, fig);

load('DP_Data_ExtraWork')

if fig == -1
    Summary(:,1) = round([mean(DP_extra_alpha0c) mean(DP_extra_alpha01c) mean(DP_extra_alpha1c) mean(DP_extra_alpha4c) mean(DP_extra_alpha10c)]',2);
    Summary(:,2) = round([std(DP_extra_alpha0c) std(DP_extra_alpha01c) std(DP_extra_alpha1c) std(DP_extra_alpha4c) std(DP_extra_alpha10c)]',2);
    Summary(:,3) = [length(DP_extra_alpha0c) length(DP_extra_alpha01c) length(DP_extra_alpha1c) length(DP_extra_alpha4c) length(DP_extra_alpha10c)]';
else

xx = linspace(0,20,21)';
alpha = [0 0.05 0.5 2 5];
WW = 100 + alpha.*xx;

rho = risk; 

if rho < 1
    U = @(om) ( (om.^(1-rho)) / (1-rho) );
elseif rho == 1
    U = @(om) (log(om));
end 

%%%%%%%%%%%%%%%%%%%%%%%

% Probability of completing extra 20 cards
A = [mean(DP_extra_alpha0c) mean(DP_extra_alpha01c) mean(DP_extra_alpha1c) mean(DP_extra_alpha4c) mean(DP_extra_alpha10c)];

[F_0c,x_0c] = ecdf(DP_extra_alpha0c);
[F_01c,x_01c] = ecdf(DP_extra_alpha01c);
[F_1c,x_1c] = ecdf(DP_extra_alpha1c);
[F_4c,x_4c] = ecdf(DP_extra_alpha4c);
[F_10c,x_10c] = ecdf(DP_extra_alpha10c);

F_0cc = [interp1(x_0c(2:end), F_0c(2:end),xx)];
F_01cc = [interp1(x_01c(2:end), F_01c(2:end),xx)];
F_1cc = [interp1(x_1c(2:end), F_1c(2:end),xx)];
F_4cc = [interp1(x_4c(2:end), F_4c(2:end),xx)];
F_10cc = [interp1(x_10c(2:end), F_10c(2:end),xx)];

FF = [F_0cc F_01cc F_1cc F_4cc F_10cc];

for k = 1:5
    dF(:,k) = [FF(1,k) ; FF(2:end,k) - FF(1:end-1,k)];
end

%%%%%%%%%%%%%%%%%%%%%%%
% A/B Tests

% Generate all pairs of A-B tests
NN=1;
for n=2:length(A)-1
    for nn=n+1:length(A)
        cnt(NN,:)=[n nn];
    NN=NN+1;
    end
end

line=1;
for counter=1:length(cnt)
    
% Set A-B test
i = cnt(counter,1);
j = cnt(counter,2);

Da = A(j)-A(i);
f_a(:,counter) = (dF(:,j) - dF(:,i)) / Da;  

for k=2:length(A)
    MI(counter,k) = sum(U(WW(:,k)) .* f_a(:,counter));
end

eps(counter) = log(A(i)./A(j)) ./ log((MI(counter,i))./(MI(counter,j)));
beta(counter) = log(A(i)) - eps(counter).*log(MI(counter,i));

pred = [2:5]; pred([i-1 j-1])=[];
for k = pred
        
    a_hat(i,j,k) = exp(beta(counter) + eps(counter).*log(MI(counter,k))); %Predict treatment k using A-B test comprising i & j
    APE(i,j,k) = 100.* abs(a_hat(i,j,k)-A(k))/A(k); % Compute corresponding APE
    Table(line,:) = [i+1 j+1 k+1 a_hat(i,j,k) A(k) APE(i,j,k)]; %Each row lists i, j, k, predicted effort, true effort, and APE
    line=line+1;
    
    f_predict(:,1,line) = FF(:,i) + (a_hat(i,j,k)-A(i)).*f_a(:,counter);
    f_predict(:,2,line) = FF(:,k);
    
end

end

%%%%%%%%%%%%%%%%%%%%%%%
% A/B/C Tests

NN=1;
for i=1:1
    for j=i+1:length(A)-1
        for k=j+1:length(A)
            cnt_abc(NN,:)=[i j k];
            NN=NN+1;
        end
    end
end

line = 1;
for counter=1:NN-1
    
i = cnt_abc(counter,1);
j = cnt_abc(counter,2);
k = cnt_abc(counter,3);

for x = 0:20
    bb = [ones(3,1) A( [i j k])'] \ dF(x+1, [i j k])';
    g(x+1,counter) = bb(1);
    h(x+1,counter) = bb(2);
end

for l=2:length(A)
    MIabc(counter,l) = sum(U(WW(:,l)) .* h(:,counter));
end

I_abc(counter) = real(fsolve(@(I) log(A(i)./A(j)) ./ log(A(i)./A(k)) - log((MIabc(counter,i)+I)./(MIabc(counter,j)+I)) ./ log((MIabc(counter,i)+I)./(MIabc(counter,k)+I)), 0.01));
I_abc(counter) = max(0,I_abc(counter));

gamma_abc(counter) = log((MIabc(counter,i)+I_abc(counter))./(MIabc(counter,j)+I_abc(counter))) ./ log(A(i)./A(j));
ln_c0_abc(counter) = log(MIabc(counter,i)+I_abc(counter)) - gamma_abc(counter).*log(A(i));

for ind = 1:length(A)
    
    if ind ~= i && ind ~= j && ind ~= k
        Table_abc(line,1:4) = [i j k ind];
        Table_abc(line,5) = exp((-ln_c0_abc(counter) + log(MIabc(counter,ind)+I_abc(counter))) ./ gamma_abc(counter));
        Table_abc(line,6) = A(ind);
        Table_abc(line,7) = 100.*abs(Table_abc(line,5) - A(ind))./A(ind);
        
        line = line+1;
    end
    
end

end

Summary = [[corr(Table(:,4), Table(:,5)) ; mean(Table(:,6)) ; max(Table(:,6))] [corr(Table_abc(:,5), Table_abc(:,6)) ; mean(Table_abc(:,7)) ; max(Table_abc(:,7))]];

plotfig = fig;

if plotfig == 1

figure('Name','Figure 12: Predicted vs. actual performance for the WWII extra-work card coding task','NumberTitle','off','units','normalized','outerposition',[0 0 1 1])
set(0,'defaultTextInterpreter','latex');
hold on; 
plot(Table(:,5),Table(:,4),'rp','markerfacecolor','red','MarkerSize',18)
plot(Table_abc(:,6), Table_abc(:,5), 'b^', 'markerfacecolor','blue','MarkerSize',12)
diag = [8 18]; plot(diag,diag,'--k','linewidth',3)
hold off
set(gca,'FontSize',20)
xlabel('True \# of additional WWII cards completed','FontSize',35); ylabel('Predicted \# of additional WWII cards completed','FontSize',35);
%title('Predictions using Homogeneous A/B Tests','FontSize',30,'FontWeight','normal')
%title('Predictions using Hybrid A/B Tests','FontSize',30,'FontWeight','normal')
legend('Predictions with $A/B$ Test', 'Predictions with $A/B_1/B_2$ Test','interpreter','latex','Location','northwest','FontSize',35);
legend('boxoff')
fig = gcf;
fig.Color = 'w';
saveas(gcf,'../Figure12.png')

end

end